import { BasePaginationData, BaseRespData } from '@/types/api'
import axios from './axios'
import {
  LogListData,
  OrderData,
  QaData,
  SearchForm,
  SendOrderData,
  ShipmentForm,
  ShipmentOrderRes,
  Tab,
  InspectionData,
} from '@/types/api/order'
import {
  DeliveryNoteData,
  DeliveryNoteSearchForm,
  ProductionOrder,
} from '@/types/api/deliveryNote'

export function getOrderList(
  data: SearchForm,
  currentPage: number,
  pageSize: number,
) {
  return axios.post<never, BasePaginationData<OrderData>>(
    '/factory/customJomallOrder/list_page',
    { ...data, currentPage, pageSize },
  )
}

export function getOrderTabData() {
  return axios.get<never, BaseRespData<Tab[]>>(
    'factory/customJomallOrder/findStateGroupList',
  )
}
// 确认生产
export function confirmProductionOrder(ids: number[]) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/confirmProduce',
    ids,
  )
}

// 下载稿件
export function downloadOrder(id: number) {
  return axios.get<never, BaseRespData<never>>(
    'factory/customJomallOrder/downloadMaterial',
    { params: { id } },
  )
}
// 重新生成稿件
export function reGenerateScriptUrlApi(ids: number[]) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/downloadAgain',
    ids,
  )
}

// 打印生产单
export function printOrder(ids: number[]) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/printProducePdf',
    ids,
  )
}

// 导出生产单
export function exportOrder(status?: string | number) {
  return axios.get<never, BaseRespData<never>>(
    'factory/customJomallOrder/exportData',
    {
      params: {
        status,
      },
    },
  )
}

// 获取订单详情
export function getOrderBySubOrderNumber(orderNumber: string) {
  return axios.get<never, BaseRespData<OrderData>>(
    'factory/customJomallOrder/getOrderBySubOrderNumber',
    {
      params: {
        subOrderNumber: orderNumber,
      },
    },
  )
}
export function getQaOrderBySubOrderNumber(orderNumber: string) {
  return axios.get<never, BaseRespData<QaData[]>>(
    'factory/customJomallOrder/inspectionQuery',
    {
      params: {
        subOrderNumber: orderNumber,
      },
    },
  )
}
// 质检完成
export function qaFinishedApi(data: InspectionData[]) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/inspection',
    data,
  )
}

// 发货保存
export function saveOrder(
  sumbitSendOutList: ShipmentOrderRes[],
  from: ShipmentForm,
) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/sendOut',
    { sumbitSendOutList, ...from },
  )
}

// 添加内部便签
export function addInternalTagApi(idList: number[], memo: string) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/batchAddInternalMemo',
    { idList, content: memo },
  )
}
// 查看发货单
export function loadSendOutList(id: number) {
  return axios.get<never, BaseRespData<SendOrderData[]>>(
    'factory/customJomallOrder/getShipmentListByCustomOrderId',
    {
      params: {
        id,
      },
    },
  )
}
// 操作日志
export function getLogList(id: number) {
  return axios.get<never, BaseRespData<LogListData[]>>(
    'factory/customJomallOrder/getLog',
    {
      params: {
        id,
      },
    },
  )
}

// 根据id获取数据详情
export function getOrderDetail(id: number) {
  return axios.get<never, BaseRespData<OrderData>>(
    'factory/customJomallOrder/getOrderById',
    {
      params: {
        id,
      },
    },
  )
}

// 取消
export function cancelOrderApi(id: number) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/cancel',
    { id },
  )
}

export function refreshProductInfo(data: number[]) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/refreshProductInfo',
    data,
  )
}
export function getDeliveryNoteList(
  data: DeliveryNoteSearchForm,
  currentPage: number,
  pageSize: number,
) {
  return axios.post<never, BasePaginationData<DeliveryNoteData>>(
    'factory/customJomallShipment/list_page',
    {
      ...data,
      currentPage,
      pageSize,
    },
  )
}
export function printDeliveryNote(data: string[]) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallShipment/printInvoiceStatistics',
    {
      startTime: data && data[0],
      endTime: data && data[1],
    },
  )
}

export function getProductionOrderList(subOrderNumber: string) {
  return axios.get<never, BaseRespData<ProductionOrder>>(
    'customJomallOrderProduct/getBySubOrderNumber',
    {
      params: {
        subOrderNumber,
      },
    },
  )
}

export function getOrderByIdApi(id?: number) {
  return axios.get<never, BaseRespData<OrderData>>(
    'factory/customJomallOrder/getOrderById',
    {
      params: {
        id,
      },
    },
  )
}
